﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace _0224ADMSample
{
    using System.IO;

    public partial class Form1 : Form
    {
        private bool PreInputInitialize = true;// 入力表示初期化前(これがtrueだと入力設定を変化させてもコマンドを送らない)
        private StreamWriter[] FileCh = new StreamWriter[2];    // 保存ファイルストリーム
        private int[] DataCnt = new int[2];// 連続サンプリング取得データ数
        private int[,,,] CalibOffset = new int[2, 2, 2, 3];// オフセット校正数値 [ch,dc/ac,sens,gain]
        private double[,,] CalibLsbv = new double[2,2,3];// スパン校正数値

        public Form1()
        {
            InitializeComponent();
        }

        // コントロールの表示状態の設定
        private void ControlEn(int st)
        {
            switch (st)
            {
                case 0: //デバイス非接続状態の時(プログラム起動直後)
                    ConnectBtn.Enabled = true;
                    DisConnectBtn.Enabled = false;
                    ADCPanel.Enabled = false;
                    SerialNumTxt.Enabled = true;
                    break;
                case 1:// デバイス接続状態　サンプリング中ではない
                    ConnectBtn.Enabled = false;
                    DisConnectBtn.Enabled = true;
                    ADCPanel.Enabled = true;
                    SerialNumTxt.Enabled = false;
                    // サンプリングしていない時のみ有効のグループ
                    SyncModeGr.Enabled = true;
                    ClockSyncGr.Enabled = true;
                    AdClockGr.Enabled = true;
                    AdInputGr1.Enabled = true;
                    AdInputGr2.Enabled = true;
                    TriggerGr.Enabled = true;
                    //サンプリングコントロールボタン
                    SmplStartBtn.Enabled = true;
                    SmplStopBtn.Enabled = false;
                    //デバイス接続制御
                    DisConnectBtn.Enabled = true;
                    //トリガボタン
                    SoftTriggerBtn.Enabled = false;
                    break;
                case 2:// デバイス接続状態　サンプリング中
                    ConnectBtn.Enabled = false;
                    DisConnectBtn.Enabled = true;
                    ADCPanel.Enabled = true;
                    SerialNumTxt.Enabled = false;
                    // サンプリングして中は無効のグループ
                    SyncModeGr.Enabled = false;
                    ClockSyncGr.Enabled = false;
                    AdClockGr.Enabled = false;
                    AdInputGr1.Enabled = false;
                    AdInputGr2.Enabled = false;
                    TriggerGr.Enabled = false;
                    //サンプリングコントロールボタン
                    SmplStartBtn.Enabled = false;
                    SmplStopBtn.Enabled = true;
                    //デバイス接続制御
                    DisConnectBtn.Enabled = false;
                    if (TriggerTypeSel.SelectedIndex == 6)
                        SoftTriggerBtn.Enabled = true;
                    else
                        SoftTriggerBtn.Enabled = false;
                    break;
            }
        }

        // Adの入力設定を確認して設定表示を変更する
        private void InputCheck()
        {
            uint ret;
            byte Sens;
            byte Couple;
            byte Gain;

            PreInputInitialize = true;

            // Ad ch1　のチェック
            ret = TUSB0224ADM.TUSB0224ADM_Ad_InputChk(SerialNumTxt.Text, 0, out Sens, out Couple, out Gain);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
            else
            {
                if (Sens == 0) Ch1Att1.Checked = true;
                else Ch1Att10.Checked = true;
                if (Couple == 0) Ch1DC.Checked = true;
                else Ch1AC.Checked = true;
                if (Gain == 0) Ch1Gain0.Checked = true;
                else if (Gain == 1) Ch1Gain1.Checked = true;
                else Ch1Gain2.Checked = true;
            }

            // Ad ch2 のチェック
            ret = TUSB0224ADM.TUSB0224ADM_Ad_InputChk(SerialNumTxt.Text, 1, out Sens, out Couple, out Gain);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
            else
            {
                if (Sens == 0) Ch2Att1.Checked = true;
                else Ch2Att10.Checked = true;
                if (Couple == 0) Ch2DC.Checked = true;
                else Ch2AC.Checked = true;
                if (Gain == 0) Ch2Gain0.Checked = true;
                else if (Gain == 1) Ch2Gain1.Checked = true;
                else Ch2Gain2.Checked = true;
            }

            PreInputInitialize = false;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            // コンボボックスの初期化
            SyncModeSel.SelectedIndex = 0;
            AdBaseRateSel.SelectedIndex = 0;
            TriggerTypeSel.SelectedIndex = 0;

            ControlEn(0);// コントロール表示状態の初期化
        }

        private void Get_Calib_Val()
        {
            int[] tmpL = new int[9];
            double[] tmpD = new double[6];

            for (byte ch = 0; ch < 2; ch++)
            {
                TUSB0224ADM.TUSB0224ADM_Calib_Val(SerialNumTxt.Text, ch, tmpL, tmpD);
                CalibOffset[ch, 0, 0, 0] = tmpL[0];
                CalibOffset[ch, 0, 0, 1] = tmpL[1];
                CalibOffset[ch, 0, 0, 2] = tmpL[2];
                CalibOffset[ch, 0, 1, 0] = tmpL[3];
                CalibOffset[ch, 0, 1, 1] = tmpL[4];
                CalibOffset[ch, 0, 1, 2] = tmpL[5];
                CalibOffset[ch, 1, 0, 0] = tmpL[6];
                CalibOffset[ch, 1, 0, 1] = tmpL[7];
                CalibOffset[ch, 1, 0, 2] = tmpL[8];
                CalibOffset[ch, 1, 1, 0] = tmpL[6];
                CalibOffset[ch, 1, 1, 1] = tmpL[7];
                CalibOffset[ch, 1, 1, 2] = tmpL[8];
                CalibLsbv[ch, 0, 0] = tmpD[0];
                CalibLsbv[ch, 0, 1] = tmpD[1];
                CalibLsbv[ch, 0, 2] = tmpD[2];
                CalibLsbv[ch, 1, 0] = tmpD[3];
                CalibLsbv[ch, 1, 1] = tmpD[4];
                CalibLsbv[ch, 1, 2] = tmpD[5];
            }
            CalibDisp1.Text =
                "Offset[0] " + CalibOffset[0, 0, 0, 0].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[1] " + CalibOffset[0, 0, 0, 1].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[2] " + CalibOffset[0, 0, 0, 2].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[3] " + CalibOffset[0, 0, 1, 0].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[4] " + CalibOffset[0, 0, 1, 1].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[5] " + CalibOffset[0, 0, 1, 2].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[6] " + CalibOffset[0, 1, 0, 0].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[7] " + CalibOffset[0, 1, 0, 1].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[8] " + CalibOffset[0, 1, 0, 2].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Lsbv  [0] " + CalibLsbv[0, 0, 0].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [1] " + CalibLsbv[0, 0, 1].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [2] " + CalibLsbv[0, 0, 2].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [3] " + CalibLsbv[0, 1, 0].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [4] " + CalibLsbv[0, 1, 1].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [5] " + CalibLsbv[0, 1, 2].ToString("0.00000000E0") + "[V/LSB]";
            CalibDisp2.Text =
                "Offset[0] " + CalibOffset[1, 0, 0, 0].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[1] " + CalibOffset[1, 0, 0, 1].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[2] " + CalibOffset[1, 0, 0, 2].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[3] " + CalibOffset[1, 0, 1, 0].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[4] " + CalibOffset[1, 0, 1, 1].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[5] " + CalibOffset[1, 0, 1, 2].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[6] " + CalibOffset[1, 1, 0, 0].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[7] " + CalibOffset[1, 1, 0, 1].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Offset[8] " + CalibOffset[1, 1, 0, 2].ToString("+000000;-000000; 000000") + "[LSB]\n" +
                "Lsbv  [0] " + CalibLsbv[1, 0, 0].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [1] " + CalibLsbv[1, 0, 1].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [2] " + CalibLsbv[1, 0, 2].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [3] " + CalibLsbv[1, 1, 0].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [4] " + CalibLsbv[1, 1, 1].ToString("0.00000000E0") + "[V/LSB]\n" +
                "Lsbv  [5] " + CalibLsbv[1, 1, 2].ToString("0.00000000E0") + "[V/LSB]";
        }

        private void ConnectBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            try
            {
                ret = TUSB0224ADM.TUSB0224ADM_Connect(SerialNumTxt.Text);
                if (ret != 0)
                    MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
                else
                {
                    Get_Calib_Val();
                    InputCheck();
                    ControlEn(1);
                    MonitorTimer.Enabled = true;
                }
            }
            catch (System.DllNotFoundException ex)// DLLが見つからない時
            {
                MessageBox.Show(ex.Message, "ErrorMessage");
                MessageBox.Show("ドライバが見つかりません。ドライバが正しくインストールされているか確認してください。", "接続時エラー");
            }
        }

        private void DisConnectBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            MonitorTimer.Enabled = false;
            ret = TUSB0224ADM.TUSB0224ADM_DisConnect(SerialNumTxt.Text);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
            ControlEn(0);
        }

        private void SyncModeSetBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            ret = TUSB0224ADM.TUSB0224ADM_SyncMode(SerialNumTxt.Text, (byte)SyncModeSel.SelectedIndex);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));

        }

        private void SyncNormalSel_CheckedChanged(object sender, EventArgs e)
        {
            uint ret;
            ret = TUSB0224ADM.TUSB0224ADM_SyncAdj(SerialNumTxt.Text, 0);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
            SyncADClkBtn.Enabled = true;
        }

        private void SyncWaitSel_CheckedChanged(object sender, EventArgs e)
        {
            uint ret;
            ret = TUSB0224ADM.TUSB0224ADM_SyncAdj(SerialNumTxt.Text, 1);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
            SyncADClkBtn.Enabled = false;
        }

        private void SyncADClkBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            ret = TUSB0224ADM.TUSB0224ADM_SyncAdj(SerialNumTxt.Text, 2);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
        }

        private void CalcSPS(object sender, EventArgs e)
        {
            double clksps = 0.0;
            double div;

            switch (AdBaseRateSel.SelectedIndex)
            {
                case 0:
                    clksps = 512000;
                    break;
                case 1:
                    clksps = 256000;
                    break;
                case 2:
                    clksps = 128000;
                    break;
                case 3:
                    clksps = 64000;
                    break;
                case 4:
                    clksps = 400000;
                    break;
                case 5:
                    clksps = 200000;
                    break;
                case 6:
                    clksps = 100000;
                    break;
                case 7:
                    clksps = 50000;
                    break;
                case 8:
                    clksps = 11291676.0 / 32.0;
                    break;
                case 9:
                    clksps = 11291676.0 / 64.0;
                    break;
                case 10:
                    clksps = 11291676.0 / 128.0;
                    break;
                case 11:
                    clksps = 11291676.0 / 256.0;
                    break;
                case 12:
                    clksps = 384000;
                    break;
                case 13:
                    clksps = 192000;
                    break;
                case 14:
                    clksps = 96000;
                    break;
                case 15:
                    clksps = 48000;
                    break;
                case 16:
                    SpsDisp.Text = "外部クロック/" + (32 * (DivRate.Value + 1)).ToString();
                    return;
                case 17:
                    SpsDisp.Text = "外部クロック/" + (64 * (DivRate.Value + 1)).ToString();
                    return;
                case 18:
                    SpsDisp.Text = "外部クロック/" + (128 * (DivRate.Value + 1)).ToString();
                    return;
                case 19:
                    SpsDisp.Text = "外部クロック/" + (256 * (DivRate.Value + 1)).ToString();
                    return;
            }
            div = (double)DivRate.Value;

            clksps /= (div + 1.0);//データレートを計算する

            if (clksps >= 100.0E3)//100kSPS台
                SpsDisp.Text = (clksps / 1000.0).ToString("0.000") + "kSPS";
            else if (clksps >= 10.0E3)//10kSPS台
                SpsDisp.Text = (clksps / 1000.0).ToString("0.000") + "kSPS";
            else if (clksps >= 1.0E3)//1kSPS台
                SpsDisp.Text = (clksps / 1000.0).ToString("0.0000") + "kSPS";
            else//1kSPS未満
                SpsDisp.Text = clksps.ToString("0.000") + "SPS";
        }

        private void AdClkSetBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            byte Sel;
            uint ClkDiv;
            byte Filter;

            Sel = (byte)AdBaseRateSel.SelectedIndex;

            ClkDiv = (uint)DivRate.Value;

            Filter = (byte)((FilterSel1.Checked) ? 0 : 1);

            ret = TUSB0224ADM.TUSB0224ADM_Ad_IntClock(SerialNumTxt.Text, Sel, ClkDiv, Filter);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
        }

        private void Ch1InputChange(object sender, EventArgs e)
        {
            uint ret;
            byte Sens;
            byte Couple;
            byte Gain;

            if (PreInputInitialize)
                return;

            if (sender.GetType().Name == "RadioButton")
            {
                if (((RadioButton)sender).Checked)
                {
                    Sens = (Ch1Att1.Checked) ? (byte)0 : (byte)1;
                    Couple = (Ch1DC.Checked) ? (byte)0 : (byte)1;
                    Gain = (Ch1Gain0.Checked) ? (byte)0 : (Ch1Gain1.Checked) ? (byte)1 : (byte)2;

                    ret = TUSB0224ADM.TUSB0224ADM_Ad_Input(SerialNumTxt.Text, 0, Sens, Couple, Gain);
                    if (ret != 0)
                        MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
                }
            }
        }

        private void Ch2InputChange(object sender, EventArgs e)
        {
            uint ret;
            byte Sens;
            byte Couple;
            byte Gain;

            if (PreInputInitialize)
                return;

            if (sender.GetType().Name == "RadioButton")
            {
                if (((RadioButton) sender).Checked)
                {
                    Sens = (Ch2Att1.Checked) ? (byte)0 : (byte)1;
                    Couple = (Ch2DC.Checked) ? (byte)0 : (byte)1;
                    Gain = (Ch2Gain0.Checked) ? (byte)0 : (Ch2Gain1.Checked) ? (byte)1 : (byte)2;

                    ret = TUSB0224ADM.TUSB0224ADM_Ad_Input(SerialNumTxt.Text, 1, Sens, Couple, Gain);
                    if (ret != 0)
                        MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
                }
            }
        }

        private void TriggerTypeSel_SelectedIndexChanged(object sender, EventArgs e)
        {
            switch (TriggerTypeSel.SelectedIndex)
            {
                case 0://アナログ立ち上がり
                case 1://アナログ立下り
                    TrgCh1.Enabled = true;
                    TrgCh2.Enabled = true;
                    TrgLevel.Enabled = true;
                    HysLevel.Enabled = true;
                    TrgWndUpper.Enabled = false;
                    TrgWndUnder.Enabled = false;
                    break;
                case 2://範囲内
                case 3://範囲外
                    TrgCh1.Enabled = true;
                    TrgCh2.Enabled = true;
                    TrgLevel.Enabled = false;
                    HysLevel.Enabled = false;
                    TrgWndUpper.Enabled = true;
                    TrgWndUnder.Enabled = true;
                    break;
                case 4://デジタル立上り
                case 5://デジタル立下り
                    TrgCh1.Enabled = false;
                    TrgCh2.Enabled = false;
                    TrgLevel.Enabled = false;
                    HysLevel.Enabled = false;
                    TrgWndUpper.Enabled = false;
                    TrgWndUnder.Enabled = false;
                    break;
                case 6://ソフトウェア
                    TrgCh1.Enabled = false;
                    TrgCh2.Enabled = false;
                    TrgLevel.Enabled = false;
                    HysLevel.Enabled = false;
                    TrgWndUpper.Enabled = false;
                    TrgWndUnder.Enabled = false;
                    break;
            }
        }

        private void TrgSetBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            byte Select;
            byte AinSel;
            int Level1;
            int Level2;

            Select = (byte)TriggerTypeSel.SelectedIndex;
            AinSel = (TrgCh1.Checked) ? (byte)0 : (byte)1;
            switch (Select)
            {
                case 0:
                case 1:
                    Level1 = (int)TrgLevel.Value;
                    Level2 = (int)HysLevel.Value;
                    break;
                case 2:
                case 3:
                    Level1 = (int)TrgWndUpper.Value;
                    Level2 = (int)TrgWndUnder.Value;
                    break;
                default:
                    Level1 = 0;
                    Level2 = 0;
                    break;

            }
            ret = TUSB0224ADM.TUSB0224ADM_Smpl_TrgLevel(SerialNumTxt.Text, Select, AinSel, Level1, Level2);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
        }

        private void SmplStartBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            uint PreTrgLen;

            PreTrgLen = (uint)PreTrg.Value;

            ret = TUSB0224ADM.TUSB0224ADM_Smpl_Start(SerialNumTxt.Text, PreTrgLen, 0);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));

            string ftimestr = DateTime.Now.ToString("yyyyMMdd_HHmmss");
            FileCh[0] = new StreamWriter(ftimestr + "_Ch1.dat");
            FileCh[1] = new StreamWriter(ftimestr + "_Ch2.dat");
            DataCnt[0] = 0;
            DataCnt[1] = 0;
            ControlEn(2);
            SmplTimer.Enabled = true;
        }

        private void SmplStopBtn_Click(object sender, EventArgs e)
        {
            uint ret;

            SmplTimer.Enabled = false;
            ret = TUSB0224ADM.TUSB0224ADM_Smpl_Stop(SerialNumTxt.Text);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
            FileCh[0].Close();
            FileCh[1].Close();
            ControlEn(1);
        }

        private void SoftTriggerBtn_Click(object sender, EventArgs e)
        {
            uint ret;

            ret = TUSB0224ADM.TUSB0224ADM_Smpl_SoftTrigger(SerialNumTxt.Text);
            if (ret != 0)
                MessageBox.Show(TUSB0224ADM.GetErrMessage(ret));
        }

        private void DOutSetBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            byte OutData;

            OutData = (DOut0Chk.Checked) ? (byte)1 : (byte)0;
            OutData += (DOut1Chk.Checked) ? (byte)2 : (byte)0;
            OutData += (DOut2Chk.Checked) ? (byte)4 : (byte)0;
            OutData += (DOut3Chk.Checked) ? (byte)8 : (byte)0;

            ret = TUSB0224ADM.TUSB0224ADM_Dio_Out(SerialNumTxt.Text, OutData);
            if (ret != 0)
                ErrorStatus.Text = TUSB0224ADM.GetErrMessage(ret);
        }

        private void DInReadBtn_Click(object sender, EventArgs e)
        {
            uint ret;
            byte InData;
            ret = TUSB0224ADM.TUSB0224ADM_Dio_In(SerialNumTxt.Text, out InData);
            if (ret != 0)
            {
                ErrorStatus.Text = TUSB0224ADM.GetErrMessage(ret);
            }
            else
            {
                DIn0Chk.Checked = ((InData & 0x01) == 0x01) ? true : false;
                DIn1Chk.Checked = ((InData & 0x02) == 0x02) ? true : false;
                DIn2Chk.Checked = ((InData & 0x04) == 0x04) ? true : false;
                DIn3Chk.Checked = ((InData & 0x08) == 0x08) ? true : false;
            }
        }

        private void SmplTimer_Tick(object sender, EventArgs e)
        {
            uint ret;

            string[] STATTXT = new string[] {
                                    "停止中",
                                    "プレトリガ長待機",
                                    "トリガ待ち",
                                    "サンプリング中",
                                    "データオーバフロー"};

            for (byte ch = 0; ch < 2; ch++)
            {
                byte Status;
                uint DataLen;

                ret = TUSB0224ADM.TUSB0224ADM_Smpl_Status(SerialNumTxt.Text, ch, out Status, out DataLen);
                if (ret != 0)
                    ErrorStatus.Text = TUSB0224ADM.GetErrMessage(ret);
                if (DataLen > 0)
                {
                    int[] Data = new int[DataLen];
                    ret = TUSB0224ADM.TUSB0224ADM_Smpl_Data(SerialNumTxt.Text, ch, Data, ref DataLen);
                    if (ret != 0)
                        ErrorStatus.Text = TUSB0224ADM.GetErrMessage(ret);
                    else
                    {
                        for (uint cnt = 0; cnt < DataLen; cnt++)
                        {
                            FileCh[ch].WriteLine(Data[cnt]);
                        }
                        DataCnt[ch] += (int)DataLen;
                    }
                }

                if (ch == 0)
                    SmplStatus1.Text = STATTXT[Status] + " Data長 = " + DataCnt[ch].ToString();
                else
                    SmplStatus2.Text = STATTXT[Status] + " Data長 = " + DataCnt[ch].ToString();
            }
        }

        private int GetCOffset(int ch)
        {
            if(ch==0)//ch1
            {
                int gain = (Ch1Gain0.Checked) ? 0 : (Ch1Gain1.Checked) ? 1 : 2;
                int sens = (Ch1Att1.Checked) ? 0 : 1;
                int couple = (Ch1DC.Checked) ? 0 : 1;
                return CalibOffset[0, couple, sens, gain];
            }
            else//ch2
            {
                int gain = (Ch2Gain0.Checked) ? 0 : (Ch2Gain1.Checked) ? 1 : 2;
                int sens = (Ch2Att1.Checked) ? 0 : 1;
                int couple = (Ch2DC.Checked) ? 0 : 1;
                return CalibOffset[1, couple, sens, gain];
            }
        }

        private double GetLsbv(int ch)
        {
            if(ch==0)//ch1
            {
                int gain = (Ch1Gain0.Checked) ? 0 : (Ch1Gain1.Checked) ? 1 : 2;
                int sens = (Ch1Att1.Checked) ? 0 : 1;
                return CalibLsbv[0, sens, gain];
            }
            else//ch2
            {
                int gain = (Ch2Gain0.Checked) ? 0 : (Ch2Gain1.Checked) ? 1 : 2;
                int sens = (Ch2Att1.Checked) ? 0 : 1;
                return CalibLsbv[1, sens, gain];
            }
        }

        private void MonitorTimer_Tick(object sender, EventArgs e)
        {
            uint ret;
            int[] Data = new int[2];

            ret = TUSB0224ADM.TUSB0224ADM_Ad_Sample(SerialNumTxt.Text, Data);
            if( ret == 0 )
            {
                double[] lsbv = new double[2];
                for ( int ch = 0; ch < 2; ch++ )
                {
                    lsbv[ch] = (double) ( Data[ch] - GetCOffset(ch)) * GetLsbv(ch);
                }
                //VInTxt1.Text = lsbv[0].ToString("+00.000000;-00.000000; 00.000000");
                //VInTxt2.Text = lsbv[1].ToString("+00.000000;-00.000000; 00.000000");
                VInTxt1.Text = lsbv[0].ToString("+00.000000;-00.000000; 00.000000");
                VInTxt2.Text = lsbv[1].ToString("+00.000000;-00.000000; 00.000000");
            }
        }
    }
}
